pub struct ContentFlags { /* private fields */ }Expand description
TACT content flags on the WoW root index.
Reference: WoWDev Wiki
Implementations
Sourceimpl ContentFlags
impl ContentFlags
Sourceimpl ContentFlags
impl ContentFlags
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl ContentFlags
impl ContentFlags
Sourcepub fn high_res_texture(&self) -> <bool as Specifier>::InOut
pub fn high_res_texture(&self) -> <bool as Specifier>::InOut
Returns the value of high_res_texture.
Is high-res texture (Cataclysm 4.4.0 beta).
Sourcepub fn high_res_texture_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn high_res_texture_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of high_res_texture.
Errors
If the returned value contains an invalid bit pattern for high_res_texture.
Is high-res texture (Cataclysm 4.4.0 beta).
Sourcepub fn with_high_res_texture(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_high_res_texture(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of high_res_texture set to the given value.
Panics
If the given value is out of bounds for high_res_texture.
Is high-res texture (Cataclysm 4.4.0 beta).
Sourcepub fn with_high_res_texture_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_high_res_texture_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of high_res_texture set to the given value.
Errors
If the given value is out of bounds for high_res_texture.
Is high-res texture (Cataclysm 4.4.0 beta).
Sourcepub fn set_high_res_texture(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_high_res_texture(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of high_res_texture to the given value.
Panics
If the given value is out of bounds for high_res_texture.
Is high-res texture (Cataclysm 4.4.0 beta).
Sourcepub fn set_high_res_texture_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_high_res_texture_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of high_res_texture to the given value.
Errors
If the given value is out of bounds for high_res_texture.
Is high-res texture (Cataclysm 4.4.0 beta).
Sourcepub fn install(&self) -> <bool as Specifier>::InOut
pub fn install(&self) -> <bool as Specifier>::InOut
Returns the value of install.
File is in install manifest.
Sourcepub fn install_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn install_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of install.
Errors
If the returned value contains an invalid bit pattern for install.
File is in install manifest.
Sourcepub fn with_install(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_install(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of install set to the given value.
Panics
If the given value is out of bounds for install.
File is in install manifest.
Sourcepub fn with_install_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_install_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of install set to the given value.
Errors
If the given value is out of bounds for install.
File is in install manifest.
Sourcepub fn set_install(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_install(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of install to the given value.
Panics
If the given value is out of bounds for install.
File is in install manifest.
Sourcepub fn set_install_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_install_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of install to the given value.
Errors
If the given value is out of bounds for install.
File is in install manifest.
Sourcepub fn windows(&self) -> <bool as Specifier>::InOut
pub fn windows(&self) -> <bool as Specifier>::InOut
Returns the value of windows.
Non-Windows clients should ignore this file.
Sourcepub fn windows_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn windows_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of windows.
Errors
If the returned value contains an invalid bit pattern for windows.
Non-Windows clients should ignore this file.
Sourcepub fn with_windows(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_windows(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of windows set to the given value.
Panics
If the given value is out of bounds for windows.
Non-Windows clients should ignore this file.
Sourcepub fn with_windows_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_windows_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of windows set to the given value.
Errors
If the given value is out of bounds for windows.
Non-Windows clients should ignore this file.
Sourcepub fn set_windows(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_windows(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of windows to the given value.
Panics
If the given value is out of bounds for windows.
Non-Windows clients should ignore this file.
Sourcepub fn set_windows_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_windows_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of windows to the given value.
Errors
If the given value is out of bounds for windows.
Non-Windows clients should ignore this file.
Sourcepub fn macos(&self) -> <bool as Specifier>::InOut
pub fn macos(&self) -> <bool as Specifier>::InOut
Returns the value of macos.
Non-macOS clients should ignore this file.
Sourcepub fn macos_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn macos_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of macos.
Errors
If the returned value contains an invalid bit pattern for macos.
Non-macOS clients should ignore this file.
Sourcepub fn with_macos(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_macos(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of macos set to the given value.
Panics
If the given value is out of bounds for macos.
Non-macOS clients should ignore this file.
Sourcepub fn with_macos_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_macos_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of macos set to the given value.
Errors
If the given value is out of bounds for macos.
Non-macOS clients should ignore this file.
Sourcepub fn set_macos(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_macos(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of macos to the given value.
Panics
If the given value is out of bounds for macos.
Non-macOS clients should ignore this file.
Sourcepub fn set_macos_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_macos_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of macos to the given value.
Errors
If the given value is out of bounds for macos.
Non-macOS clients should ignore this file.
Sourcepub fn x86_32_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn x86_32_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of x86_32.
Errors
If the returned value contains an invalid bit pattern for x86_32.
x86_32 binary.
Sourcepub fn with_x86_32(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_x86_32(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of x86_32 set to the given value.
Panics
If the given value is out of bounds for x86_32.
x86_32 binary.
Sourcepub fn with_x86_32_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_x86_32_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of x86_32 set to the given value.
Errors
If the given value is out of bounds for x86_32.
x86_32 binary.
Sourcepub fn set_x86_32(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_x86_32(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of x86_32 to the given value.
Panics
If the given value is out of bounds for x86_32.
x86_32 binary.
Sourcepub fn set_x86_32_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_x86_32_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of x86_32 to the given value.
Errors
If the given value is out of bounds for x86_32.
x86_32 binary.
Sourcepub fn x86_64_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn x86_64_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of x86_64.
Errors
If the returned value contains an invalid bit pattern for x86_64.
x86_64 binary.
Sourcepub fn with_x86_64(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_x86_64(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of x86_64 set to the given value.
Panics
If the given value is out of bounds for x86_64.
x86_64 binary.
Sourcepub fn with_x86_64_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_x86_64_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of x86_64 set to the given value.
Errors
If the given value is out of bounds for x86_64.
x86_64 binary.
Sourcepub fn set_x86_64(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_x86_64(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of x86_64 to the given value.
Panics
If the given value is out of bounds for x86_64.
x86_64 binary.
Sourcepub fn set_x86_64_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_x86_64_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of x86_64 to the given value.
Errors
If the given value is out of bounds for x86_64.
x86_64 binary.
Sourcepub fn low_violence(&self) -> <bool as Specifier>::InOut
pub fn low_violence(&self) -> <bool as Specifier>::InOut
Returns the value of low_violence.
Low violence variant.
Sourcepub fn low_violence_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn low_violence_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of low_violence.
Errors
If the returned value contains an invalid bit pattern for low_violence.
Low violence variant.
Sourcepub fn with_low_violence(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_low_violence(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of low_violence set to the given value.
Panics
If the given value is out of bounds for low_violence.
Low violence variant.
Sourcepub fn with_low_violence_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_low_violence_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of low_violence set to the given value.
Errors
If the given value is out of bounds for low_violence.
Low violence variant.
Sourcepub fn set_low_violence(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_low_violence(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of low_violence to the given value.
Panics
If the given value is out of bounds for low_violence.
Low violence variant.
Sourcepub fn set_low_violence_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_low_violence_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of low_violence to the given value.
Errors
If the given value is out of bounds for low_violence.
Low violence variant.
Sourcepub fn mystery_platform(&self) -> <bool as Specifier>::InOut
pub fn mystery_platform(&self) -> <bool as Specifier>::InOut
Returns the value of mystery_platform.
Non-mystery-platform clients should ignore this file.
Sourcepub fn mystery_platform_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn mystery_platform_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of mystery_platform.
Errors
If the returned value contains an invalid bit pattern for mystery_platform.
Non-mystery-platform clients should ignore this file.
Sourcepub fn with_mystery_platform(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_mystery_platform(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of mystery_platform set to the given value.
Panics
If the given value is out of bounds for mystery_platform.
Non-mystery-platform clients should ignore this file.
Sourcepub fn with_mystery_platform_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_mystery_platform_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of mystery_platform set to the given value.
Errors
If the given value is out of bounds for mystery_platform.
Non-mystery-platform clients should ignore this file.
Sourcepub fn set_mystery_platform(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_mystery_platform(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of mystery_platform to the given value.
Panics
If the given value is out of bounds for mystery_platform.
Non-mystery-platform clients should ignore this file.
Sourcepub fn set_mystery_platform_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_mystery_platform_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of mystery_platform to the given value.
Errors
If the given value is out of bounds for mystery_platform.
Non-mystery-platform clients should ignore this file.
Sourcepub fn update_plugin(&self) -> <bool as Specifier>::InOut
pub fn update_plugin(&self) -> <bool as Specifier>::InOut
Returns the value of update_plugin.
Only set for UpdatePlugin.{dll,dylib}
Sourcepub fn update_plugin_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn update_plugin_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of update_plugin.
Errors
If the returned value contains an invalid bit pattern for update_plugin.
Only set for UpdatePlugin.{dll,dylib}
Sourcepub fn with_update_plugin(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_update_plugin(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of update_plugin set to the given value.
Panics
If the given value is out of bounds for update_plugin.
Only set for UpdatePlugin.{dll,dylib}
Sourcepub fn with_update_plugin_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_update_plugin_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of update_plugin set to the given value.
Errors
If the given value is out of bounds for update_plugin.
Only set for UpdatePlugin.{dll,dylib}
Sourcepub fn set_update_plugin(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_update_plugin(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of update_plugin to the given value.
Panics
If the given value is out of bounds for update_plugin.
Only set for UpdatePlugin.{dll,dylib}
Sourcepub fn set_update_plugin_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_update_plugin_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of update_plugin to the given value.
Errors
If the given value is out of bounds for update_plugin.
Only set for UpdatePlugin.{dll,dylib}
Sourcepub fn aarch64(&self) -> <bool as Specifier>::InOut
pub fn aarch64(&self) -> <bool as Specifier>::InOut
Returns the value of aarch64.
aarch64 / ARM64 binary.
Sourcepub fn aarch64_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn aarch64_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of aarch64.
Errors
If the returned value contains an invalid bit pattern for aarch64.
aarch64 / ARM64 binary.
Sourcepub fn with_aarch64(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_aarch64(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of aarch64 set to the given value.
Panics
If the given value is out of bounds for aarch64.
aarch64 / ARM64 binary.
Sourcepub fn with_aarch64_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_aarch64_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of aarch64 set to the given value.
Errors
If the given value is out of bounds for aarch64.
aarch64 / ARM64 binary.
Sourcepub fn set_aarch64(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_aarch64(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of aarch64 to the given value.
Panics
If the given value is out of bounds for aarch64.
aarch64 / ARM64 binary.
Sourcepub fn set_aarch64_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_aarch64_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of aarch64 to the given value.
Errors
If the given value is out of bounds for aarch64.
aarch64 / ARM64 binary.
Sourcepub fn encrypted_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn encrypted_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of encrypted.
Errors
If the returned value contains an invalid bit pattern for encrypted.
Sourcepub fn with_encrypted(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_encrypted(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of encrypted set to the given value.
Panics
If the given value is out of bounds for encrypted.
Sourcepub fn with_encrypted_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_encrypted_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of encrypted set to the given value.
Errors
If the given value is out of bounds for encrypted.
Sourcepub fn set_encrypted(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_encrypted(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of encrypted to the given value.
Panics
If the given value is out of bounds for encrypted.
Sourcepub fn set_encrypted_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_encrypted_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of encrypted to the given value.
Errors
If the given value is out of bounds for encrypted.
Sourcepub fn no_name_hash(&self) -> <bool as Specifier>::InOut
pub fn no_name_hash(&self) -> <bool as Specifier>::InOut
Returns the value of no_name_hash.
Sourcepub fn no_name_hash_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn no_name_hash_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of no_name_hash.
Errors
If the returned value contains an invalid bit pattern for no_name_hash.
Sourcepub fn with_no_name_hash(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_no_name_hash(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of no_name_hash set to the given value.
Panics
If the given value is out of bounds for no_name_hash.
Sourcepub fn with_no_name_hash_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_no_name_hash_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of no_name_hash set to the given value.
Errors
If the given value is out of bounds for no_name_hash.
Sourcepub fn set_no_name_hash(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_no_name_hash(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of no_name_hash to the given value.
Panics
If the given value is out of bounds for no_name_hash.
Sourcepub fn set_no_name_hash_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_no_name_hash_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of no_name_hash to the given value.
Errors
If the given value is out of bounds for no_name_hash.
Sourcepub fn uncommon_resolution(&self) -> <bool as Specifier>::InOut
pub fn uncommon_resolution(&self) -> <bool as Specifier>::InOut
Returns the value of uncommon_resolution.
Non-1280px wide cinematics.
Sourcepub fn uncommon_resolution_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn uncommon_resolution_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of uncommon_resolution.
Errors
If the returned value contains an invalid bit pattern for uncommon_resolution.
Non-1280px wide cinematics.
Sourcepub fn with_uncommon_resolution(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_uncommon_resolution( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of uncommon_resolution set to the given value.
Panics
If the given value is out of bounds for uncommon_resolution.
Non-1280px wide cinematics.
Sourcepub fn with_uncommon_resolution_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_uncommon_resolution_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of uncommon_resolution set to the given value.
Errors
If the given value is out of bounds for uncommon_resolution.
Non-1280px wide cinematics.
Sourcepub fn set_uncommon_resolution(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_uncommon_resolution(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of uncommon_resolution to the given value.
Panics
If the given value is out of bounds for uncommon_resolution.
Non-1280px wide cinematics.
Sourcepub fn set_uncommon_resolution_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_uncommon_resolution_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of uncommon_resolution to the given value.
Errors
If the given value is out of bounds for uncommon_resolution.
Non-1280px wide cinematics.
Sourcepub fn bundle_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn bundle_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of bundle.
Errors
If the returned value contains an invalid bit pattern for bundle.
Sourcepub fn with_bundle(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_bundle(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of bundle set to the given value.
Panics
If the given value is out of bounds for bundle.
Sourcepub fn with_bundle_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_bundle_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of bundle set to the given value.
Errors
If the given value is out of bounds for bundle.
Sourcepub fn set_bundle(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_bundle(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of bundle to the given value.
Panics
If the given value is out of bounds for bundle.
Sourcepub fn set_bundle_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_bundle_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of bundle to the given value.
Errors
If the given value is out of bounds for bundle.
Sourcepub fn no_compression(&self) -> <bool as Specifier>::InOut
pub fn no_compression(&self) -> <bool as Specifier>::InOut
Returns the value of no_compression.
Sourcepub fn no_compression_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn no_compression_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of no_compression.
Errors
If the returned value contains an invalid bit pattern for no_compression.
Sourcepub fn with_no_compression(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_no_compression(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of no_compression set to the given value.
Panics
If the given value is out of bounds for no_compression.
Sourcepub fn with_no_compression_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_no_compression_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of no_compression set to the given value.
Errors
If the given value is out of bounds for no_compression.
Sourcepub fn set_no_compression(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_no_compression(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of no_compression to the given value.
Panics
If the given value is out of bounds for no_compression.
Sourcepub fn set_no_compression_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_no_compression_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of no_compression to the given value.
Errors
If the given value is out of bounds for no_compression.